@@ -43,7 +43,9 @@ def write_json_to_file(__json: dict, dst: str):
         raise TypeError
 
     # write
-    open(dst, "w+", encoding="utf-8").write(json.dumps(__json, indent=4))
+    with open(dst, "w+", encoding="utf-8") as _json:
+        _json.truncate(0)
+        _json.write(json.dumps(__json, indent=4))
 
 
 def prettify(__collection, __indent=4):
